@@ -170,6 +170,8 @@ class Deployer(object):
         queue_functions = self._get_queue_functions()
         schedule_functions = self._get_schedule_functions()
 
+        hosted_zone = ".".join(self.domain.split(".")[-2:]) if self.domain else None
+
         rendered = template.render(
             description="Test",
             functions=lambda_functions,
@@ -179,7 +181,7 @@ class Deployer(object):
             project_name=self.project_name,
             subdomain=self.subdomain,
             domain=self.domain,
-            hosted_zone=".".join(self.domain.split(".")[-2:]),
+            hosted_zone=hosted_zone,
             queues=queues,
             queue_functions=queue_functions,
             schedule_functions=schedule_functions,
@@ -267,10 +269,7 @@ class Deployer(object):
         )
         self._build()
         env_vars = self._get_env_vars()
-        overrides = [
-            f"ParameterKey={x['alpha_name']},ParameterValue={x['value']}"
-            for x in env_vars
-        ]
+        overrides = [f"{x['alpha_name']}={x['value']}" for x in env_vars]
         sam_deploy = [
             "sam",
             "deploy",
@@ -282,9 +281,9 @@ class Deployer(object):
             f"{self.project_name}-bld-{self.environment}",
             "--template-file",
             ".aws-sam/build/template.yaml",
+            "--no-fail-on-empty-changeset",
             "--parameter-overrides",
             f"ENVIRONMENT={self.environment}",
-            "--no-fail-on-empty-changeset",
         ]
         if len(overrides) > 0:
             sam_deploy.append(",".join(overrides))
